# mpddrp
mpddrp is a simple python script that displays what you're currently listening to through MPD on Discord.
## Dependencies
* [pypresence](https://github.com/qwertyquerty/pypresence)
* [python-mpd2](https://github.com/Mic92/python-mpd2)
## How to run
Install using : 
`pip install mpddrp`

## Configuration
The configuration file is located at:

Windows:
`C:/Users/USERNAME/AppData/Roaming/mpddrp/config`

UNIX:
`$HOME/.config/mpddrp/config`
